PseuToPy
========

General description
-------------------

PseuToPy is a Python library which defines a grammar for a
pseudocode-based pseudocode. With this grammar, PseuToPy is then able to
take instructions written in pseudocode and converts it into the
equivalent Python instructions.

PseuToPy is designed for educational purposes. In that sense, PseuToPy
is suited to anyone embarking in the journey of learning Python
programming by offering a relaxed syntax and a grammar that very much
resembles the grammar of a natural language.

This repository is a rebuild of 
`this one <https://github.com/PatWg/PseuToPy>`__, with a new grammar file that
is taken from the Python 3.8 grammar definition.

The development is still on-going to catch up with the aforementioned
repository. But once this new project reaches (or surpasses) the state of the
former project, I will migrate the old project's code into this repository
here, so as to keep the names of the inital contributors.
